FlatQueryParams class

Flat query parameters.

Inheritance

Constructors

FlatQueryParams({bool isUsingRefiner = false, double scaleFactor = 10.0})
Create Flat query parameters.

Properties

hashCode int
The hash code for this object.
no setterinherited
isLinear bool
Get whether linear search is enabled.
no setter
isUsingRefiner bool
Get whether refiner is enabled.
no setter
nativePtr Pointer<zvec_flat_query_params_t>
The native pointer (type-erased) for passing to vector query.
no setteroverride
radius double
Get search radius.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor double
Get scale factor.
no setter

Methods

cloneNativePtr() Pointer<zvec_flat_query_params_t>
Create a native copy for APIs that take ownership of query params.
override
destroy() → void
Destroy the native query params.
destroyNativePtr(Pointer<NativeType> ptr) → void
Destroy a native copy created by cloneNativePtr if ownership was not transferred.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited