WriteResult class

Result of a batch write operation (insert/update/upsert/delete).

Constructors

WriteResult(int successCount, int errorCount, [List<WriteStatus> details = const []])
const

Properties

details List<WriteStatus>
Per-input write statuses. Result index corresponds to input index.
final
errorCount int
Number of documents that failed to process.
final
errorMessages List<String>
Error messages from failed write statuses.
no setter
errors List<WriteStatus>
Failed per-input statuses.
no setter
hashCode int
The hash code for this object.
no setterinherited
isAllSuccess bool
Whether all documents were processed successfully.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successCount int
Number of documents successfully processed.
final
totalCount int
Total number of documents in the batch.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited