VectorSchema class
Convenience class for creating vector field schemas.
Equivalent to FieldSchema with a vector data type pre-configured.
- Inheritance
-
- Object
- FieldSchema
- VectorSchema
Constructors
- VectorSchema(String name, int dimension, {DataType dataType = DataType.vectorFp32, IndexParams? indexParams})
- Create a vector field schema.
Properties
- dataType → DataType
-
Get the data type.
no setterinherited
- dimension → int
-
Get the vector dimension (0 for non-vector fields).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIndex → bool
-
Whether this field has an index.
no setterinherited
- indexType → IndexType
-
Get the index type.
no setterinherited
- isDenseVector → bool
-
Whether this is a dense vector field.
no setterinherited
- isNullable → bool
-
Whether the field is nullable.
no setterinherited
- isSparseVector → bool
-
Whether this is a sparse vector field.
no setterinherited
- isVectorField → bool
-
Whether this is a vector field (dense or sparse).
no setterinherited
- name → String
-
Get the field name.
no setterinherited
-
nativePtr
→ Pointer<
zvec_field_schema_t> -
The native pointer for internal use.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
destroy(
) → void -
Destroy the native field schema. Only call if this object owns the pointer.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setIndexParams(
IndexParams params) → void -
Set index parameters for this field.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited